@@ -168,11 +168,11 @@ class _DbMap(Psygres):
     def _load_map(map_file):
         from speaker import Speaker
         from os import path
-        if not path.isfile(map_file, 'rb'):
+        if not path.isfile(map_file):
             Speaker.log_int_raise("Mother Map %s does not exist.", ERR_COL(map_file)) 
         
         try:
-            fil= open(map_file)
+            fil= open(map_file, 'rb')
         except:
             Speaker.log_int_raise("Unable to open Mother Map %s.", ERR_COL(map_file)) 
 
@@ -441,9 +441,20 @@ class DbMother(_DbMap):
         res= []
 
         params= params and set(params) or set()
+        _s= self._store
+        _m= self._mo_false_values
 
         for k in self.pkeys | params:
-            res.append('%s= %%(%s)s' % (k, k))
+
+            # If the field has a no-value (NULL or DEFAULT)
+            # it's excluded from the filter
+            v= _s[k]
+            if v == SQL_DEFAULT:
+                continue
+            if v == SQL_NULL:
+                res.append('%s IS NULL' % k)
+            else:
+                res.append('%s= %%(%s)s' % (k, k))
 
         res= _A(res)
         return self._sqlMogrify(res)
@@ -830,6 +841,9 @@ class DbMother(_DbMap):
 
         # the store acts as a filter..
         params= set(self._store.keys())
+        #_i= self._store.iteritems
+        #params= set([k for k, v in _i() if v 
+        #             not in self._mo_false_values]
 
         # Make the query ...
         qry= self._sqlDelete(params)
@@ -1848,6 +1862,7 @@ class MotherBox(Psygres):
         res= self.mr_query(qry)
         session= self.session
         mothers= [self.builder(d, session= session) for d in res]
+        return mothers
 
     def _trigger_mothers(self, mothers, flag, when):
         for m in mothers:
